@@ -6,7 +6,7 @@ use core::ffi::c_void;
 ///     `const NSTDByte *const other` - Pointer to memory to be copied from.
 ///     `const NSTDUSize size` - Number of bytes to copy.
 #[inline]
-#[no_mangle]
+#[cfg_attr(feature = "clib", no_mangle)]
 pub unsafe extern "C" fn nstd_core_mem_copy(copycat: *mut u8, other: *const u8, size: usize) {
     core::ptr::copy(other, copycat, size);
 }
@@ -17,7 +17,7 @@ pub unsafe extern "C" fn nstd_core_mem_copy(copycat: *mut u8, other: *const u8,
 ///     `NSTDByte *const to` - Memory to be moved to.
 ///     `const NSTDUSize size` - Number of bytes to move.
 #[inline]
-#[no_mangle]
+#[cfg_attr(feature = "clib", no_mangle)]
 pub unsafe extern "C" fn nstd_core_mem_move(from: *mut u8, to: *mut u8, size: usize) {
     nstd_core_mem_copy(to, from, size);
     for i in 0..size {
@@ -31,7 +31,7 @@ pub unsafe extern "C" fn nstd_core_mem_move(from: *mut u8, to: *mut u8, size: us
 ///     `void *const ptr2` - Second pointer to memory to swap.
 ///     `const NSTDUSize size` - Number of bytes to swap.
 #[inline]
-#[no_mangle]
+#[cfg_attr(feature = "clib", no_mangle)]
 pub unsafe extern "C" fn nstd_core_mem_switch(ptr1: *mut c_void, ptr2: *mut c_void, size: usize) {
     let x = core::slice::from_raw_parts_mut(ptr1 as *mut u8, size);
     let y = core::slice::from_raw_parts_mut(ptr2 as *mut u8, size);
@@ -44,7 +44,7 @@ pub unsafe extern "C" fn nstd_core_mem_switch(ptr1: *mut c_void, ptr2: *mut c_vo
 ///     `const NSTDUSize size` - Size of block.
 ///     `const NSTDByte byte` - Byte to fill with.
 #[inline]
-#[no_mangle]
+#[cfg_attr(feature = "clib", no_mangle)]
 pub unsafe extern "C" fn nstd_core_mem_fill(ptr: *mut u8, size: usize, byte: u8) {
     for i in 0..size {
         (*ptr.add(i)) = byte;
@@ -57,7 +57,7 @@ pub unsafe extern "C" fn nstd_core_mem_fill(ptr: *mut u8, size: usize, byte: u8)
 ///     `NSTDUSize start` - Starting index of memory to be zeroed.
 ///     `const NSTDUSize end` - Ending index of memory to be zeroed. (Excluded).
 #[inline]
-#[no_mangle]
+#[cfg_attr(feature = "clib", no_mangle)]
 pub unsafe extern "C" fn nstd_core_mem_zero(ptr: *mut u8, mut start: usize, end: usize) {
     while start < end {
         (*ptr.add(start)) = 0;
